==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp1221_001/MP1221_RefreshInventoryTransaction_001.java <==

package net.datastream.schemas.mp_functions.mp1221_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.inventorytransaction_001.InventoryTransaction;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/InventoryTransaction_001}InventoryTransaction"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Refresh" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="InventoryTransaction" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="refreshConfirm" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "inventoryTransaction"
})
@XmlRootElement(name = "MP1221_RefreshInventoryTransaction_001")
public class MP1221_RefreshInventoryTransaction_001 {

    @XmlElement(name = "InventoryTransaction", namespace = "http://schemas.datastream.net/MP_entities/InventoryTransaction_001", required = true)
    protected InventoryTransaction inventoryTransaction;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "refreshConfirm")
    protected String refreshConfirm;

    /**
     * Gets the value of the inventoryTransaction property.
     * 
     * @return
     *     possible object is
     *     {@link InventoryTransaction }
     *     
     */
    public InventoryTransaction getInventoryTransaction() {
        return inventoryTransaction;
    }

    /**
     * Sets the value of the inventoryTransaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link InventoryTransaction }
     *     
     */
    public void setInventoryTransaction(InventoryTransaction value) {
        this.inventoryTransaction = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REFRESH;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.INVENTORY_TRANSACTION;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the refreshConfirm property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRefreshConfirm() {
        if (refreshConfirm == null) {
            return "false";
        } else {
            return refreshConfirm;
        }
    }

    /**
     * Sets the value of the refreshConfirm property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRefreshConfirm(String value) {
        this.refreshConfirm = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_functions/mp1221_001/MP1221_RefreshInventoryTransaction_001.java <==

package net.datastream.schemas.mp_functions.mp1221_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.inventorytransaction_001.InventoryTransaction;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/InventoryTransaction_001}InventoryTransaction"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Refresh" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="InventoryTransaction" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="refreshConfirm" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "inventoryTransaction"
})
@XmlRootElement(name = "MP1221_RefreshInventoryTransaction_001")
public class MP1221_RefreshInventoryTransaction_001 {

    @XmlElement(name = "InventoryTransaction", namespace = "http://schemas.datastream.net/MP_entities/InventoryTransaction_001", required = true)
    protected InventoryTransaction inventoryTransaction;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "refreshConfirm")
    protected String refreshConfirm;

    /**
     * Gets the value of the inventoryTransaction property.
     * 
     * @return
     *     possible object is
     *     {@link InventoryTransaction }
     *     
     */
    public InventoryTransaction getInventoryTransaction() {
        return inventoryTransaction;
    }

    /**
     * Sets the value of the inventoryTransaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link InventoryTransaction }
     *     
     */
    public void setInventoryTransaction(InventoryTransaction value) {
        this.inventoryTransaction = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REFRESH;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.INVENTORY_TRANSACTION;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the refreshConfirm property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRefreshConfirm() {
        if (refreshConfirm == null) {
            return "false";
        } else {
            return refreshConfirm;
        }
    }

    /**
     * Sets the value of the refreshConfirm property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRefreshConfirm(String value) {
        this.refreshConfirm = value;
    }

}
